Learn R Programming

multigraph (version 1.0)

conc: Concentric Layout

Description

A function to compute the graph coordinated system with a concentric layout.

Usage

conc(net, nr, irot, inv, iflip, mirror = c("N", "X", "Y", "D", "L"), ...)

Value

A data frame with a coordinated system with two columns representing the abscissa and the ordinate in a two-dimensional rectangular Cartesian coordinate system.

Arguments

net

Array representing the network relations.

nr

Scalar with number of radii, or a vector with clustering of actors.

irot

Scalar or vector with “internal rotation” for each circle from closer to centre point to further away.

inv

(optional and logical) Invert circles ordering?

iflip

(optional and logical) Alternate circles flipping?

mirror

Mirror transformation:

  • N Identity (default)

  • X Reflection through the vertical centre line

  • Y Reflection through the horizontal centre line

  • D Reflection across diagonal \(Y=X\)

  • L Reflection across diagonal \(Y=-X\)

...

Additional argument items.

Details

An “Euclidean plane” computes the coordinated system with a concentric layout with at least two radii (unless \(n = 1\)). In case that the number of radii is not specified in nr, approx. half of the vertices are located at one radius and half in another one.

The clustering of the actors may be used to establish the location of the vertices in different radii as a numerical, character, or a factor vector.

See Also

multigraph, bmgraph, frcd, stsm

Examples

Run this code
# Two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 3 ) )

# Coordinates for the concentric layout with two radii
coord <- conc(arr, nr = 2)

# Plot multigraph with customized coordinates
multigraph(arr, coord = coord)

Run the code above in your browser using DataLab