dl Format.External datasets in multigraph package are for illustration purposes, and they have a Ucinet dl format.
The four datasets need to be transformed with function read.dl from multiplex package
for visualization according to the nature of the network.
davis.dl Southern woman: (Davis, Gardner, Gardner, 1941) affiliation network \(18 \times 14\).
sampson.dl Monastery novices: (Sampson, 1969) directed, multiplex, valued, longitudinal network \(18 \times 18 \times 10\).
padgett.dl Florentine families: (Padgett and Ansell, 1993) undirected, multiplex network \(16 \times 16 \times 2\).
padgw.dl Florentine families' attributes: table \(16 \times 3\).